@@ -56,7 +56,7 @@ my %doc_for = (
             descr      => 'Who to blame for the app',
             type       => 'pair',
             multiple   => 1,
-            urgency    => 10,
+            urgency    => 1,
             pair_labels => [ 'Name', 'Email Address' ],
             pair_required => 0,
         },
@@ -434,13 +434,15 @@ my %doc_for = (
             urgency     => 0,
         },
         extra_keys => {
-            keyword     => 'extra_keys',
-            label       => 'Keys for form hash',
-            descr       => 'Extra keys to put in the form method hash',
-            type        => 'text',
-            applies_to  => 'forms',
-            multiple    => 1,
-            urgency     => 0,
+            keyword       => 'extra_keys',
+            label         => 'Keys for form hash',
+            descr         => 'Extra keys to put in the form method hash',
+            type          => 'pair',
+            pair_labels   => [ 'key', 'value' ],
+            pair_required => 1,
+            applies_to    => 'forms',
+            multiple      => 1,
+            urgency       => 0,
         },
         all_fields_but => {
             keyword     => 'all_fields_but',
